**Example 1: RedeployEdgeUnitApplication**



Input: 

```
tccli iecp RedeployEdgeUnitApplication --cli-unfold-argument  \
    --EdgeUnitId 1 \
    --ApplicationId 1
```

Output: 
```
{
    "Response": {
        "RequestId": "5ebf13a2-f925-4ba7-adff-ddbc21d355e3"
    }
}
```

